diff mbox

[OSSTEST] Allow longer timeout when creating backing file for a raw disk.

Message ID 1452860638-1845-1-git-send-email-ian.campbell@citrix.com (mailing list archive)
State New, archived
Headers show

Commit Message

Ian Campbell Jan. 15, 2016, 12:23 p.m. UTC
I noticed this dd timiung out when recommissioning the 3 cubietrucks
(picasso, metzinger, gleizes) but looking at the log shows this has
been happening on braque too.

The current code assumes 65MB/s arriving at a timeout of 153s for the
10G file. On arndale-* the logs indicate that it is achieving 95MB/s
and taking 105-107s which results in a warning but not a failure:

   execution took 105 seconds [**>153.846153846154/2**]

In experiments on a local cubietruck I observed it achieving a much
lower throughput of 40MB/s, which seems to be consistent with what
others are seeing:
https://groups.google.com/forum/#!category-topic/cubieboard/troubleshooting/7R4HlCDNCTU

Therefore calculate the timeout assuming a throughput of 20MB/s, in
practice for a 10GB file this will result in a 500s timeout.

Signed-off-by: Ian Campbell <ian.campbell@citrix.com>
---
 Osstest/TestSupport.pm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

Comments

Ian Jackson Jan. 15, 2016, 4:42 p.m. UTC | #1
Ian Campbell writes ("[PATCH OSSTEST] Allow longer timeout when creating backing file for a raw disk."):
> I noticed this dd timiung out when recommissioning the 3 cubietrucks
> (picasso, metzinger, gleizes) but looking at the log shows this has
> been happening on braque too.
> 
> The current code assumes 65MB/s arriving at a timeout of 153s for the
> 10G file. On arndale-* the logs indicate that it is achieving 95MB/s
> and taking 105-107s which results in a warning but not a failure:
> 
>    execution took 105 seconds [**>153.846153846154/2**]
> 
> In experiments on a local cubietruck I observed it achieving a much
> lower throughput of 40MB/s, which seems to be consistent with what
> others are seeing:
> https://groups.google.com/forum/#!category-topic/cubieboard/troubleshooting/7R4HlCDNCTU
> 
> Therefore calculate the timeout assuming a throughput of 20MB/s, in
> practice for a 10GB file this will result in a 500s timeout.

Acked-by: Ian Jackson <ian.jackson@eu.citrix.com>
diff mbox

Patch

diff --git a/Osstest/TestSupport.pm b/Osstest/TestSupport.pm
index 28ac572..962d773 100644
--- a/Osstest/TestSupport.pm
+++ b/Osstest/TestSupport.pm
@@ -1747,9 +1747,9 @@  sub make_qcow2 ($$$) {
 }
 sub make_raw ($$$) {
     my ($ho, $gho, $disk_mb) = @_;
     # In local tests this reported 130MB/s, so calculate a timeout assuming 65MB/s.
     target_cmd_root($ho, "dd if=/dev/zero of=$gho->{Rootimg} bs=1MB count=${disk_mb}",
-	${disk_mb} / 65);
+	${disk_mb} / 20);
 }
 
 sub prepareguest_part_diskimg ($$$) {
@@ -1747,9 +1747,9 @@  sub make_qcow2 ($$$) {
 sub make_raw ($$$) {
     my ($ho, $gho, $disk_mb) = @_;
-    # In local tests this reported 130MB/s, so calculate a timeout assuming 65MB/s.
+    # In local tests this reported 40MB/s, so calculate a timeout assuming 20MB/s.
     target_cmd_root($ho, "dd if=/dev/zero of=$gho->{Rootimg} bs=1MB count=${disk_mb}",